@@ -106,6 +106,8 @@ FASST_STAGE_KEY = ['Wake',
                    'NREM3',
                    None,
                    'REM',
+                   'Movement',
+                   'Unknown'
                    ]
 
 PRANA_STAGE_KEY =  {'0': 'Wake',
@@ -178,7 +180,7 @@ def create_empty_annotations(xml_file, dataset):
         f.write(xml.toxml())
 
 
-def create_annotation(xml_file, from_fasst):
+def create_annotation(xml_file, from_fasst, lights_off=False, legacy_meth=False):
     """Create annotations by importing from FASST sleep scoring file.
 
     Parameters
@@ -187,6 +189,10 @@ def create_annotation(xml_file, from_fasst):
         annotation file that will be created
     from_fasst : path to FASST file
         .mat file containing the scores
+    lights_off : bool
+        set to True if scoring begins at lights off
+    legacy_meth : bool
+        old functionality; will stage epochs starting at epoch_start = 0.
 
     Returns
     -------
@@ -213,7 +219,9 @@ def create_annotation(xml_file, from_fasst):
     microsecond, second = modf(info.hour[2])
     start_time = datetime(*info.date, int(info.hour[0]), int(info.hour[1]),
                           int(second), int(microsecond * 1e6))
-    first_sec = score[3, 0][0]
+    first_sec = 0
+    if lights_off:
+        first_sec = int(round(score[3, 0][0]))
     last_sec = score[0, 0].shape[0] * score[2, 0]
 
     root = Element('annotations')
@@ -235,7 +243,7 @@ def create_annotation(xml_file, from_fasst):
     x.text = start_time.isoformat()
 
     x = SubElement(info, 'first_second')
-    x.text = str(int(first_sec))
+    x.text = str(first_sec)
     x = SubElement(info, 'last_second')
     x.text = str(int(last_sec))
 
@@ -251,11 +259,62 @@ def create_annotation(xml_file, from_fasst):
         epoch_length = int(score[2, i_rater])
         annot.add_rater(rater_name, epoch_length=epoch_length)
 
-        for epoch_start, epoch in enumerate(score[0, i_rater]):
-            if isnan(epoch):
-                continue
-            annot.set_stage_for_epoch(epoch_start * epoch_length,
-                                      FASST_STAGE_KEY[int(epoch)], save=False)
+        if not legacy_meth:
+            offset = first_sec % epoch_length
+            annot.get_rater(rater_name)
+            stages = annot.rater.find('stages')
+    
+            # list is necessary so that it does not remove in place
+            for s in list(stages):
+                stages.remove(s)
+    
+            for i in arange(offset, first_sec - epoch_length, epoch_length):
+                epoch = SubElement(stages, 'epoch')
+    
+                start_time = SubElement(epoch, 'epoch_start')
+                epoch_beg = i
+                start_time.text = str(epoch_beg)
+    
+                end_time = SubElement(epoch, 'epoch_end')
+                end_time.text = str(epoch_beg + epoch_length)
+    
+                epoch_stage = SubElement(epoch, 'stage')
+                epoch_stage.text = 'Unknown'
+                quality = SubElement(epoch, 'quality')
+                quality.text = 'Good'
+    
+            idx_epoch = 0
+            for idx_epoch, fasst_stage in enumerate(score[0, i_rater]):
+                epoch = SubElement(stages, 'epoch')
+    
+                start_time = SubElement(epoch, 'epoch_start')
+                epoch_beg = first_sec + (idx_epoch * epoch_length)
+                start_time.text = str(epoch_beg)
+    
+                end_time = SubElement(epoch, 'epoch_end')
+                end_time.text = str(epoch_beg + epoch_length)
+    
+                epoch_stage = SubElement(epoch, 'stage')
+    
+                try:
+                    one_stage = FASST_STAGE_KEY[int(fasst_stage)]
+    
+                except:
+                    one_stage = 'Unknown'
+                    lg.info(f'Stage not recognized at second {epoch_beg}')
+    
+                epoch_stage.text = one_stage
+    
+                quality = SubElement(epoch, 'quality')
+                quality.text = 'Good'
+
+        else:
+
+            for epoch_start, epoch in enumerate(score[0, i_rater]):
+                if isnan(epoch):
+                    continue
+                annot.set_stage_for_epoch(epoch_start * epoch_length,
+                                          FASST_STAGE_KEY[int(epoch)], save=False)
 
     annot.save()
 
@@ -467,10 +526,13 @@ class Annotations():
 
         elif source == 'remlogic':
             clue = 'SLEEP-' # signifies an epoch (as opposed to an event)
+            time_hdrs = ('Time [hh:mm:ss]', 'Heure [hh:mm:ss]')
             redherring = 'SPINDLE'
             idx_clue = slice(-18, -6)
             idx_head = lines.index(
-                    next(l for l in lines if 'Time [hh:mm:ss]' in l))
+                    next(l for l in lines if any(
+                                            hdr in l for hdr in time_hdrs
+                                            )))
             first_line = next(l for l in lines[idx_head:] \
                               if clue in l[idx_clue] \
                               and 'SLEEP-RM' not in l[-18:])
@@ -2098,19 +2160,28 @@ class Annotations():
 
             with open(filename, 'r', encoding='ISO-8859-1') as f:
                 lines = f.readlines()
-
+                time_hdrs = ('Time [hh:mm:ss', 'Heure [hh:mm:ss')
                 idx_header = lines.index(next(
-                        l for l in lines if 'Time [hh:mm:ss]' in l))
+                    l for l in lines if any(hdr in l for hdr in time_hdrs)))
                 header = lines[idx_header].split('\t')
                 header = [s.strip() for s in header] # remove trailing newline
-                idx_time = header.index('Time [hh:mm:ss]')
-                idx_evt = header.index('Event')
-                idx_dur = header.index('Duration[s]')
+                
+                idx_time = [i for i, s in enumerate(header) if any(
+                    x in s for x in time_hdrs)][0]
+                idx_evt = [i for i, s in enumerate(header) if any(
+                    x in s for x in (
+                        'Event', 'vènement', 'vénement', 'venement') )][0]
+                idx_dur = [i for i, s in enumerate(header) if any(
+                    x in s for x in ('Duration', 'Durée') )][0]
+                
+                # French files are in 24-hour time
+                hour24 = 'Heure' in header[idx_time]
 
                 # Find staging start date
+                date_line = lines[3].strip()
                 stage_start_date = _try_parse_datetime(
-                        lines[3][16:lines[3].index('\n')],
-                        ('%Y/%m/%d', '%d/%m/%Y'))
+                    date_line[date_line.index(':') + 2:],
+                        ('%Y/%m/%d', '%d/%m/%Y', '%Y.%m.%d', '%d.%m.%Y'))
 
                 # Events loop
                 for l in lines[idx_header + 1:]:
@@ -2122,7 +2193,8 @@ class Annotations():
                         continue
 
                     clock_start = _remlogic_time(cells[idx_time],
-                                                 stage_start_date)
+                                                 stage_start_date,
+                                                 hour24=hour24)
                     start = float((clock_start - rec_start).total_seconds())
 
                     one_ev = {'name': one_evttype,
@@ -2297,7 +2369,7 @@ def _try_parse_datetime(text, fmts):
             pass
     raise ValueError('No valid date found.')
 
-def _remlogic_time(time_cell, date):
+def _remlogic_time(time_cell, date, hour24):
     """Reads RemLogic time string to datetime
 
     Parameters
@@ -2306,21 +2378,30 @@ def _remlogic_time(time_cell, date):
         entire time cell from text file
     date : datetime
         start date from text file
+    hour24 : bool
+        if True, time will be read on 24-hour clock instead of 12-hour clock
 
     Returns
     -------
     datetime
         date and time
     """
-    stage_start_time = datetime.strptime(time_cell[-8:], '%I:%M:%S')
-    start = datetime.combine(date.date(), stage_start_time.time())
-
-    if time_cell[1] == 'U':
-        start = start + timedelta(hours=12)
-    elif time_cell[-8:-10] == '12':
-        start = start + timedelta(hours=12)
+    time_str = time_cell[time_cell.index(':') - 2:]
+    if hour24:
+        stage_start_time = _try_parse_datetime(time_str, 
+                                               ('%H:%M:%S', '%H:%M:%S.%f'))
+        start = datetime.combine(date.date(), stage_start_time.time())
     else:
-        start = start + timedelta(hours=24)
+        stage_start_time = _try_parse_datetime(time_str, 
+                                               ('%I:%M:%S', '%I:%M:%S.%f'))
+        start = datetime.combine(date.date(), stage_start_time.time())
+    
+        if time_cell[1] == 'U':
+            start = start + timedelta(hours=12)
+        elif time_cell[-8:-10] == '12':
+            start = start + timedelta(hours=12)
+        else:
+            start = start + timedelta(hours=24)
 
     return start
 
